======
Anyfig
======


.. image:: https://img.shields.io/pypi/v/anyfig.svg
        :target: https://pypi.python.org/pypi/anyfig
        
.. image:: https://img.shields.io/pypi/pyversions/anyfig.svg
        :target: https://pypi.org/project/anyfig/

.. image:: https://img.shields.io/travis/OlofHarrysson/anyfig.svg?logo=travis
        :target: https://travis-ci.com/OlofHarrysson/anyfig


Anyfig is a Python library for creating configurations (settings) at runtime. Anyfig utilizes Python classes which empowers the developer to put anything, from strings to custom objects in the config. Hence the name Any(con)fig.

Please read more at our website [https://anyfig.now.sh/](https://anyfig.now.sh/)

* Free software: MIT license
